﻿using System;
using System.Collections.Generic;
using System.Data;
using System.Data.Entity;
using System.Data.Entity.Infrastructure;
using System.Linq;
using System.Net;
using System.Net.Http;
using System.Web.Http;
using System.Web.Http.Description;
using ContactLibrary;
using DAL;
using DAL.Repositories;

namespace WebApiApp.Controllers
{
    public class PeopleController : ApiController
    {
        //private DataBaseContext db = new DataBaseContext();
        //private readonly PersonRepository _repoPerson = 
        //    new PersonRepository(new DataBaseContext());

        private readonly PersonRepository _repoPerson;

        public PeopleController(PersonRepository repoPerson)
        {
            _repoPerson = repoPerson;
        }


        // GET: api/People
        public IQueryable<Person> GetPersons()
        {
            return _repoPerson.All;
        }

        // GET: api/People/5
        [ResponseType(typeof(Person))]
        public IHttpActionResult GetPerson(int id)
        {
            Person person = _repoPerson.GetById(id);
            if (person == null)
            {
                return NotFound();
            }

            return Ok(person);
        }

        // PUT: api/People/5
        [ResponseType(typeof(void))]
        public IHttpActionResult PutPerson(int id, Person person)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            if (id != person.PersonID)
            {
                return BadRequest();
            }

            _repoPerson.Update(person);

            try
            {
                _repoPerson.Save();
            }
            catch (DbUpdateConcurrencyException)
            {
                if (!PersonExists(id))
                {
                    return NotFound();
                }
                else
                {
                    throw;
                }
            }

            return StatusCode(HttpStatusCode.NoContent);
        }

        // POST: api/People
        [ResponseType(typeof(Person))]
        public IHttpActionResult PostPerson(Person person)
        {
            if (!ModelState.IsValid)
            {
                return BadRequest(ModelState);
            }

            _repoPerson.Add(person);
            _repoPerson.Save();

            return CreatedAtRoute("DefaultApi", new { id = person.PersonID }, person);
        }

        // DELETE: api/People/5
        [ResponseType(typeof(Person))]
        public IHttpActionResult DeletePerson(int id)
        {
            Person person = _repoPerson.GetById(id);
            if (person == null)
            {
                return NotFound();
            }

            _repoPerson.Delete(id);
            _repoPerson.Save();

            return Ok(person);
        }

        protected override void Dispose(bool disposing)
        {
            if (disposing)
            {
                _repoPerson.Dispose();
            }
            base.Dispose(disposing);
        }

        private bool PersonExists(int id)
        {
            return _repoPerson.All.Count(e => e.PersonID == id) > 0;
        }
    }
}